==> types_boto3_resource_groups-1.35.71-py3-none-any.whl: types_boto3_resource_groups/paginator.py <==
"""
Type annotations for resource-groups service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_resource_groups.client import ResourceGroupsClient
    from types_boto3_resource_groups.paginator import (
        ListGroupResourcesPaginator,
        ListGroupingStatusesPaginator,
        ListGroupsPaginator,
        ListTagSyncTasksPaginator,
        SearchResourcesPaginator,
    )

    session = Session()
    client: ResourceGroupsClient = session.client("resource-groups")

    list_group_resources_paginator: ListGroupResourcesPaginator = client.get_paginator("list_group_resources")
    list_grouping_statuses_paginator: ListGroupingStatusesPaginator = client.get_paginator("list_grouping_statuses")
    list_groups_paginator: ListGroupsPaginator = client.get_paginator("list_groups")
    list_tag_sync_tasks_paginator: ListTagSyncTasksPaginator = client.get_paginator("list_tag_sync_tasks")
    search_resources_paginator: SearchResourcesPaginator = client.get_paginator("search_resources")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListGroupingStatusesInputListGroupingStatusesPaginateTypeDef,
    ListGroupingStatusesOutputTypeDef,
    ListGroupResourcesInputListGroupResourcesPaginateTypeDef,
    ListGroupResourcesOutputTypeDef,
    ListGroupsInputListGroupsPaginateTypeDef,
    ListGroupsOutputTypeDef,
    ListTagSyncTasksInputListTagSyncTasksPaginateTypeDef,
    ListTagSyncTasksOutputTypeDef,
    SearchResourcesInputSearchResourcesPaginateTypeDef,
    SearchResourcesOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListGroupResourcesPaginator",
    "ListGroupingStatusesPaginator",
    "ListGroupsPaginator",
    "ListTagSyncTasksPaginator",
    "SearchResourcesPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListGroupResourcesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListGroupResources.html#ResourceGroups.Paginator.ListGroupResources)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listgroupresourcespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListGroupResourcesInputListGroupResourcesPaginateTypeDef]
    ) -> _PageIterator[ListGroupResourcesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListGroupResources.html#ResourceGroups.Paginator.ListGroupResources.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listgroupresourcespaginator)
        """


class ListGroupingStatusesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListGroupingStatuses.html#ResourceGroups.Paginator.ListGroupingStatuses)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listgroupingstatusespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListGroupingStatusesInputListGroupingStatusesPaginateTypeDef]
    ) -> _PageIterator[ListGroupingStatusesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListGroupingStatuses.html#ResourceGroups.Paginator.ListGroupingStatuses.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listgroupingstatusespaginator)
        """


class ListGroupsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListGroups.html#ResourceGroups.Paginator.ListGroups)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listgroupspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListGroupsInputListGroupsPaginateTypeDef]
    ) -> _PageIterator[ListGroupsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListGroups.html#ResourceGroups.Paginator.ListGroups.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listgroupspaginator)
        """


class ListTagSyncTasksPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListTagSyncTasks.html#ResourceGroups.Paginator.ListTagSyncTasks)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listtagsynctaskspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListTagSyncTasksInputListTagSyncTasksPaginateTypeDef]
    ) -> _PageIterator[ListTagSyncTasksOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListTagSyncTasks.html#ResourceGroups.Paginator.ListTagSyncTasks.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listtagsynctaskspaginator)
        """


class SearchResourcesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/SearchResources.html#ResourceGroups.Paginator.SearchResources)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#searchresourcespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[SearchResourcesInputSearchResourcesPaginateTypeDef]
    ) -> _PageIterator[SearchResourcesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/SearchResources.html#ResourceGroups.Paginator.SearchResources.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#searchresourcespaginator)
        """

==> types_boto3_resource_groups-1.35.93-py3-none-any.whl: types_boto3_resource_groups/paginator.py <==
"""
Type annotations for resource-groups service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_resource_groups.client import ResourceGroupsClient
    from types_boto3_resource_groups.paginator import (
        ListGroupResourcesPaginator,
        ListGroupingStatusesPaginator,
        ListGroupsPaginator,
        ListTagSyncTasksPaginator,
        SearchResourcesPaginator,
    )

    session = Session()
    client: ResourceGroupsClient = session.client("resource-groups")

    list_group_resources_paginator: ListGroupResourcesPaginator = client.get_paginator("list_group_resources")
    list_grouping_statuses_paginator: ListGroupingStatusesPaginator = client.get_paginator("list_grouping_statuses")
    list_groups_paginator: ListGroupsPaginator = client.get_paginator("list_groups")
    list_tag_sync_tasks_paginator: ListTagSyncTasksPaginator = client.get_paginator("list_tag_sync_tasks")
    search_resources_paginator: SearchResourcesPaginator = client.get_paginator("search_resources")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListGroupingStatusesInputPaginateTypeDef,
    ListGroupingStatusesOutputTypeDef,
    ListGroupResourcesInputPaginateTypeDef,
    ListGroupResourcesOutputTypeDef,
    ListGroupsInputPaginateTypeDef,
    ListGroupsOutputTypeDef,
    ListTagSyncTasksInputPaginateTypeDef,
    ListTagSyncTasksOutputTypeDef,
    SearchResourcesInputPaginateTypeDef,
    SearchResourcesOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListGroupResourcesPaginator",
    "ListGroupingStatusesPaginator",
    "ListGroupsPaginator",
    "ListTagSyncTasksPaginator",
    "SearchResourcesPaginator",
)


if TYPE_CHECKING:
    _ListGroupResourcesPaginatorBase = Paginator[ListGroupResourcesOutputTypeDef]
else:
    _ListGroupResourcesPaginatorBase = Paginator  # type: ignore[assignment]


class ListGroupResourcesPaginator(_ListGroupResourcesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListGroupResources.html#ResourceGroups.Paginator.ListGroupResources)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listgroupresourcespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListGroupResourcesInputPaginateTypeDef]
    ) -> PageIterator[ListGroupResourcesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListGroupResources.html#ResourceGroups.Paginator.ListGroupResources.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listgroupresourcespaginator)
        """


if TYPE_CHECKING:
    _ListGroupingStatusesPaginatorBase = Paginator[ListGroupingStatusesOutputTypeDef]
else:
    _ListGroupingStatusesPaginatorBase = Paginator  # type: ignore[assignment]


class ListGroupingStatusesPaginator(_ListGroupingStatusesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListGroupingStatuses.html#ResourceGroups.Paginator.ListGroupingStatuses)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listgroupingstatusespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListGroupingStatusesInputPaginateTypeDef]
    ) -> PageIterator[ListGroupingStatusesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListGroupingStatuses.html#ResourceGroups.Paginator.ListGroupingStatuses.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listgroupingstatusespaginator)
        """


if TYPE_CHECKING:
    _ListGroupsPaginatorBase = Paginator[ListGroupsOutputTypeDef]
else:
    _ListGroupsPaginatorBase = Paginator  # type: ignore[assignment]


class ListGroupsPaginator(_ListGroupsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListGroups.html#ResourceGroups.Paginator.ListGroups)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listgroupspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListGroupsInputPaginateTypeDef]
    ) -> PageIterator[ListGroupsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListGroups.html#ResourceGroups.Paginator.ListGroups.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listgroupspaginator)
        """


if TYPE_CHECKING:
    _ListTagSyncTasksPaginatorBase = Paginator[ListTagSyncTasksOutputTypeDef]
else:
    _ListTagSyncTasksPaginatorBase = Paginator  # type: ignore[assignment]


class ListTagSyncTasksPaginator(_ListTagSyncTasksPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListTagSyncTasks.html#ResourceGroups.Paginator.ListTagSyncTasks)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listtagsynctaskspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTagSyncTasksInputPaginateTypeDef]
    ) -> PageIterator[ListTagSyncTasksOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/ListTagSyncTasks.html#ResourceGroups.Paginator.ListTagSyncTasks.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#listtagsynctaskspaginator)
        """


if TYPE_CHECKING:
    _SearchResourcesPaginatorBase = Paginator[SearchResourcesOutputTypeDef]
else:
    _SearchResourcesPaginatorBase = Paginator  # type: ignore[assignment]


class SearchResourcesPaginator(_SearchResourcesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/SearchResources.html#ResourceGroups.Paginator.SearchResources)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#searchresourcespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[SearchResourcesInputPaginateTypeDef]
    ) -> PageIterator[SearchResourcesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups/paginator/SearchResources.html#ResourceGroups.Paginator.SearchResources.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_resource_groups/paginators/#searchresourcespaginator)
        """
